Module extensions

Module extensions 

Extension point for customizing the C# code generation pipeline.

Structs

PostModelPass
Mutable references to model passes, provided to extensions after each model cycle.
PostOutputPass
References to output passes, provided to extensions after output rendering.

Traits

RustCodegenExtension
Trait for extensions that hook into the C# code generation pipeline.