DotnetLibrary

Struct DotnetLibrary 

pub struct DotnetLibrary { /* private fields */ }
Available on crate feature unstable-plugins only.
Code generation pipeline for .NET plugins (reverse interop).

Analogous to RustLibrary but takes a ForeignInventory describing types and functions exposed by a .NET assembly rather than to one.

Implementations

Source

impl DotnetLibrary

pub fn new(inventory: ForeignInventory) -> Self

Available on crate feature unstable-plugins or docsrs only.
pub fn builder(inventory: ForeignInventory) -> DotnetLibraryBuilder

Available on crate feature unstable-plugins or docsrs only.
pub fn process(self) -> Result<Multibuf, Error>

Available on crate feature unstable-plugins or docsrs only.

Runs the code generation pipeline and returns the generated output buffers.