pub struct RustLibraryBuilder { /* private fields */ }Expand description
Builder for configuring and constructing a RustLibrary.
Implementations
Sourceimpl RustLibraryBuilder
impl RustLibraryBuilder
Sourcepub fn dispatch(self, dispatch: Dispatch) -> Self
pub fn dispatch(self, dispatch: Dispatch) -> Self
Sets the dispatch strategy that routes items to output files.
Sourcepub fn dll_name(self, dll_name: impl AsRef<str>) -> Self
pub fn dll_name(self, dll_name: impl AsRef<str>) -> Self
Sets the native library name used in [DllImport("...")] declarations.
Sourcepub fn headers(self, header_config: HeaderConfig) -> Self
pub fn headers(self, header_config: HeaderConfig) -> Self
Configures the generation of the file header.
Sourcepub fn search_path(self, search_path: SearchPathConfig) -> Self
pub fn search_path(self, search_path: SearchPathConfig) -> Self
What DLL loading policies to emit.
Sourcepub fn with_extension(
self,
extension: impl RustCodegenExtension + 'static,
) -> Self
pub fn with_extension( self, extension: impl RustCodegenExtension + 'static, ) -> Self
Registers an extension that can hook into model and output passes.
Sourcepub fn build(self) -> RustLibrary
pub fn build(self) -> RustLibrary
Builds the configured RustLibrary, ready for process.